OrderedCollection subclass:#Stack
	instanceVariableNames:''
	classVariableNames:''
	poolDictionaries:''
	category:'Collections-Ordered'
!

!Stack class methodsFor:'documentation'!

documentation
"
    a simple implementation of a Stack.

    [author:]
        Stefan Vogel

    [see also:]
        OrderedCollection Queue
"
!

examples
"
  push-push-....
                                                                [exBegin]
    |aStack|

    aStack := Stack new.
    Transcript showCR:aStack.
    Transcript showCR:'push 1: '.
    aStack push:1.
    Transcript showCR:'push 2: '.
    aStack push:2.
    Transcript showCR:'push 3: '.
    aStack push:3.
    Transcript showCR:aStack.
    Transcript show:'pop: '; showCR:(aStack pop).
    Transcript show:'pop: '; showCR:(aStack pop).
    Transcript show:'pop: '; showCR:(aStack pop).
    Transcript showCR:aStack.
                                                                [exEnd]

  popping too many:
                                                                [exBegin]
    |aStack|

    aStack := Stack new.
    aStack push:1.

    aStack pop.
    aStack pop.
                                                                [exEnd]
"
! !

!Stack class methodsFor:'instance creation'!

new
        ^self new: 100
! !

!Stack methodsFor:'accessing'!

pop
        "Answer the object on top of the stack."

    ^ self removeLast

    "Created: 7.2.1996 / 00:12:53 / stefan"
    "Modified: 7.2.1996 / 00:13:53 / stefan"
!

pop: numElem 
        "Pop and discard top numElems and answer receiver"

        self removeLast:numElem

    "Created: 7.2.1996 / 00:12:53 / stefan"
    "Modified: 7.2.1996 / 00:14:16 / stefan"
!

push: anObject 
        "Push anObject onto the top of the stack."

    ^ self add:anObject

    "Created: 7.2.1996 / 00:12:53 / stefan"
    "Modified: 7.2.1996 / 00:14:52 / stefan"
!

top
        "Answer (without removing) the object on top of the stack."

        ^self last

    "Created: 7.2.1996 / 00:12:54 / stefan"
    "Modified: 7.2.1996 / 00:15:26 / stefan"
! !

!Stack methodsFor:'enumerating'!

do: aBlock
        "Evaluate aBlock for each object on the stack, from top to bottom."

        ^ super reverseDo:aBlock

    "Created: 7.2.1996 / 00:12:53 / stefan"
    "Modified: 7.2.1996 / 00:16:00 / stefan"
!

reverseDo: aBlock
        "Evaluate aBlock for each object on the stack, from bottom to top."

        ^ super do:aBlock

    "Created: 7.2.1996 / 00:12:54 / stefan"
    "Modified: 7.2.1996 / 00:16:18 / stefan"
! !

!Stack class methodsFor:'documentation'!

version
    ^ '$Header: /cvs/stx/stx/libbasic2/Stack.st,v 1.3 1997-01-16 13:03:14 cg Exp $'
! !
